@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,6 @@
 
 #include "folder/foldersettings.h"
 #include "kernel/mailkernel.h"
-#include "util/mailutil_p.h"
 #include <PimCommonAkonadi/CollectionAnnotationsAttribute>
 #include <PimCommonAkonadi/ContentTypeWidget>
 #include <PimCommonAkonadi/IncidencesForWidget>
@@ -23,7 +22,6 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <PimCommon/PimUtil>
 
-#include <KIdentityManagement/IdentityCombo>
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <PimCommonAkonadi/ImapResourceCapabilitiesManager>
 
